@@ -9,7 +9,7 @@ use Mojo::Util qw/slurp dumper/;
 
 use JavaScript::V8::Handlebars;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 has 'wrapper';
 
@@ -64,6 +64,9 @@ sub register {
 		if( length $options->{inline} ) {
 			$$output = $hbjs->render_string( $options->{inline}, $c->stash );
 		}
+		elsif( $options->{template} ) {
+			$$output = $hbjs->execute_template( $options->{template}, $c->stash );
+		}
 		elsif( my $template = $r->template_for($c) ) {
 			$$output = $hbjs->execute_template( $template, $c->stash );
 		}
@@ -99,8 +102,11 @@ This is a plugin for adding the Handlebars templating language to Mojolicious as
 		...
 	}
 
-Note that by default when this plugin is initialized it attempts to cache every .hbs file inside your templates directory, which includes registering any files under a directory named 'partials' as a partial with the same name as the file. You can also pass a wrapper file which is executed after any render call and passed the results of the first render as the variable 'content'. Specifying a helpers.js file allow you to execute Handlebars.registerHelper() statements to provide functions to your templates. Or really, any other code you want. 
+Note that by default when this plugin is initialized it attempts to cache every .hbs file inside your templates directory, which includes registering any files under a directory named 'partials' as a partial with the same name as the file. You can also pass a wrapper file which is executed after any render call and passed the results of the first render as the variable 'content'. 
 
+Specifying a helpers.js file allow you to execute Handlebars.registerHelper() statements to provide functions to your templates. Or really, any other code you want. Any JS in this file is executed in the same global context that contains the Handlebars object that containers registeredHelpers, stored templates and is invokved to compile and execute new templates.
+
+Automatically found parsers are stored as 'partial/partialname'; for example: ./templates/partials/things/myfoo.hbs; may be accessed as C<< {{>partials/things/myfoo}} >>
 
 =head1 AUTHOR
 
